@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import abc
 import copy
 
@@ -8,10 +7,6 @@ from numpy.testing import assert_allclose, assert_array_equal
 from pytest import approx
 
 import boost_histogram as bh
-import boost_histogram.utils
-
-# compatible with Python 2 *and* 3:
-ABC = abc.ABCMeta("ABC", (object,), {"__slots__": ()})
 
 
 @pytest.mark.parametrize(
@@ -40,8 +35,10 @@ ABC = abc.ABCMeta("ABC", (object,), {"__slots__": ()})
         (bh.axis.Integer, (1, 2), "", {"circular": True}),
         (bh.axis.IntCategory, ((1, 2, 3),), "", {}),
         (bh.axis.IntCategory, ((1, 2, 3),), "g", {}),
+        (bh.axis.IntCategory, ((),), "g", {}),
         (bh.axis.StrCategory, (tuple("ABC"),), "", {}),
         (bh.axis.StrCategory, (tuple("ABC"),), "g", {}),
+        (bh.axis.StrCategory, ((),), "g", {}),
     ],
 )
 def test_metadata(axis, args, opt, kwargs):
@@ -76,7 +73,7 @@ def test_metadata(axis, args, opt, kwargs):
     assert ax.__dict__ == {"metadata": 5}
     assert ax.metadata == 5
 
-    # Python 2 does not allow mixing ** and kw
+    # Python 2 did not allow mixing ** and kw
     new_kwargs = copy.copy(kwargs)
     new_kwargs["__dict__"] = {"something": 2}
     new_kwargs["metadata"] = 3
@@ -91,9 +88,9 @@ def test_metadata(axis, args, opt, kwargs):
 
 
 # The point of this ABC is to force all the tests listed here to be implemented
-# for each axis type. PyTest instantiates these test classes for us, so missing
+# for each axis type. Pytest instantiates these test classes for us, so missing
 # one really does fail the test.
-class Axis(ABC):
+class Axis(abc.ABC):
     @abc.abstractmethod
     def test_init(self):
         pass
@@ -200,6 +197,8 @@ class TestRegular(Axis):
         assert a != bh.axis.Regular(3, 1.0, 2.0)
         assert a != bh.axis.Regular(4, 1.1, 2.0)
         assert a != bh.axis.Regular(4, 1.0, 2.1)
+        assert a != object()
+        assert not (a == object())  # __eq__ and __ne__ are separately implemented
 
         # metadata compare
         assert bh.axis.Regular(1, 2, 3, metadata=1) == bh.axis.Regular(
@@ -223,16 +222,16 @@ class TestRegular(Axis):
         assert repr(ax) == "Regular(4, 1.1, 2.2)"
 
         ax = bh.axis.Regular(4, 1.1, 2.2, metadata="ra")
-        assert repr(ax) == "Regular(4, 1.1, 2.2)"
+        assert repr(ax) == "Regular(4, 1.1, 2.2, metadata='ra')"
 
         ax = bh.axis.Regular(4, 1.1, 2.2, underflow=False)
         assert repr(ax) == "Regular(4, 1.1, 2.2, underflow=False)"
 
         ax = bh.axis.Regular(4, 1.1, 2.2, metadata="ra", overflow=False)
-        assert repr(ax) == "Regular(4, 1.1, 2.2, overflow=False)"
+        assert repr(ax) == "Regular(4, 1.1, 2.2, overflow=False, metadata='ra')"
 
         ax = bh.axis.Regular(4, 1.1, 2.2, metadata="ra", circular=True)
-        assert repr(ax) == "Regular(4, 1.1, 2.2, circular=True)"
+        assert repr(ax) == "Regular(4, 1.1, 2.2, circular=True, metadata='ra')"
 
         ax = bh.axis.Regular(4, 1.1, 2.2, transform=bh.axis.transform.log)
         assert repr(ax) == "Regular(4, 1.1, 2.2, transform=log)"
@@ -328,12 +327,12 @@ class TestRegular(Axis):
 
         assert a.index(-1) == 2
         assert a.index(0.99) == -1
-        assert a.index(1.0) == 0
+        assert a.index(1.001) == 0
         assert a.index(9.99) == 0
-        assert a.index(10.0) == 1
+        assert a.index(10.01) == 1
         assert a.index(99.9) == 1
-        assert a.index(100) == 2
-        assert a.index(1000) == 2
+        assert a.index(100.01) == 2
+        assert a.index(1000.1) == 2
 
         assert a.bin(0)[0] == approx(1e0)
         assert a.bin(1)[0] == approx(1e1)
@@ -407,7 +406,7 @@ class TestCircular(Axis):
         assert repr(ax) == "Regular(4, 1.1, 2.2, circular=True)"
 
         ax = bh.axis.Regular(4, 1.1, 2.2, metadata="hi", circular=True)
-        assert repr(ax) == "Regular(4, 1.1, 2.2, circular=True)"
+        assert repr(ax) == "Regular(4, 1.1, 2.2, circular=True, metadata='hi')"
 
     def test_getitem(self):
         a = bh.axis.Regular(2, 1, 1 + np.pi * 2, circular=True)
@@ -520,7 +519,7 @@ class TestVariable(Axis):
         assert repr(a) == "Variable([-0.1, 0.2])"
 
         a = bh.axis.Variable([-0.1, 0.2], metadata="hi")
-        assert repr(a) == "Variable([-0.1, 0.2])"
+        assert repr(a) == "Variable([-0.1, 0.2], metadata='hi')"
 
     def test_getitem(self):
         ref = [-0.1, 0.2, 0.3]
@@ -639,7 +638,10 @@ class TestInteger:
         assert repr(a) == "Integer(-1, 1)"
 
         a = bh.axis.Integer(-1, 1, metadata="hi")
-        assert repr(a) == "Integer(-1, 1)"
+        assert repr(a) == "Integer(-1, 1, metadata='hi')"
+
+        a = bh.axis.Integer(-1, 1, metadata=2)
+        assert repr(a) == "Integer(-1, 1, metadata=...)"
 
         a = bh.axis.Integer(-1, 1, underflow=False)
         assert repr(a) == "Integer(-1, 1, underflow=False)"
@@ -728,10 +730,6 @@ class TestCategory(Axis):
         assert isinstance(ax, bh.axis.IntCategory)
         assert ax.traits == bh.axis.Traits(overflow=True)
 
-        with pytest.warns(FutureWarning):
-            assert not ax.options.underflow
-            assert ax.options.overflow
-
         ax = bh.axis.IntCategory([1, 2, 3], growth=True)
         assert isinstance(ax, bh.axis.IntCategory)
         assert ax.traits == bh.axis.Traits(growth=True)
@@ -763,14 +761,10 @@ class TestCategory(Axis):
         assert repr(ax) == "IntCategory([1, 2, 3])"
 
         ax = bh.axis.IntCategory([1, 2, 3], metadata="foo")
-        assert repr(ax) == "IntCategory([1, 2, 3])"
+        assert repr(ax) == "IntCategory([1, 2, 3], metadata='foo')"
 
         ax = bh.axis.StrCategory("ABC", metadata="foo")
-        # If unicode is the default (Python 3, generally)
-        if type("") == type(u""):  # noqa: E721
-            assert repr(ax) == "StrCategory(['A', 'B', 'C'])"
-        else:
-            assert repr(ax) == "StrCategory([u'A', u'B', u'C'])"
+        assert repr(ax) == "StrCategory(['A', 'B', 'C'], metadata='foo')"
 
     @pytest.mark.parametrize("ref", ([1, 2, 3], "ABC"))
     def test_getitem(self, ref, growth):
@@ -806,12 +800,21 @@ class TestCategory(Axis):
     )
     def test_index(self, ref, growth):
         Cat = bh.axis.StrCategory if isinstance(ref[0], str) else bh.axis.IntCategory
-        a = Cat(ref[:-1], growth=growth)
+        a = Cat(ref, growth=growth)
         for i, r in enumerate(ref):
             assert a.index(r) == i
         assert_array_equal(a.index(ref), [0, 1, 2, 3])
         assert_array_equal(a.index(np.reshape(ref, (2, 2))), [[0, 1], [2, 3]])
 
+        if isinstance(ref[0], str):
+            with pytest.raises(KeyError):
+                a.index("E")
+        else:
+            with pytest.raises(KeyError):
+                a.index(5)
+            with pytest.raises(KeyError):
+                a.index(-2)
+
     @pytest.mark.parametrize("ref", ([1, 2, 3], ("A", "B", "C")))
     def test_value(self, ref, growth):
         Cat = bh.axis.StrCategory if isinstance(ref[0], str) else bh.axis.IntCategory
@@ -868,7 +871,7 @@ class TestBoolean:
         assert repr(a) == "Boolean()"
 
         a = bh.axis.Boolean(metadata="hi")
-        assert repr(a) == "Boolean()"
+        assert repr(a) == "Boolean(metadata='hi')"
 
     def test_label(self):
         a = bh.axis.Boolean(metadata="foo")
