@@ -902,7 +902,7 @@ def test_numpy_conversion_5():
         a.fill(2, 1)
     a1 = a.view()
     assert a1.shape == (3, 2)
-    assert a1[0, 0] == float(2 ** 80)
+    assert a1[0, 0] == float(2**80)
     assert a1[1, 0] == 1
     assert a1[2, 0] == 2
     assert a1[0, 1] == 3
@@ -972,7 +972,7 @@ def test_fill_with_sequence_1():
 
     a = bh.Histogram(bh.axis.Integer(0, 3), storage=bh.storage.Weight())
     v = fa(-1, 0, 1, 2, 3, 4)
-    w = fa(2, 3, 4, 5, 6, 7)  # noqa
+    w = fa(2, 3, 4, 5, 6, 7)
     a.fill(v, weight=w)
     a.fill((0, 1), weight=(2, 3))
 
